@@ -333,10 +333,9 @@ func printOptions(buf *bytes.Buffer, cmd *cobra.Command) error {
 // GenRootMarkdownCustom creates custom markdown for the root command with preserved intro content
 func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf := new(bytes.Buffer)
-	name := cmd.CommandPath()
 	// GitLab Specific Docs Metadata
 	buf.WriteString("---" + "\n")
-	buf.WriteString("title: " + name + "\n")
+	buf.WriteString("title: GitLab CLI (glab)\n")
 	buf.WriteString("stage: Create" + "\n")
 	buf.WriteString("group: Code Review" + "\n")
 	buf.WriteString("info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/product/ux/technical-writing/#assignments" + "\n")
@@ -348,8 +347,13 @@ func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf.WriteString("Please do not edit this file directly. Run `make gen-docs` instead." + "\n")
 	buf.WriteString("-->" + "\n\n")
 
+	// Add details shortcode
+	buf.WriteString("{{< details >}}\n\n")
+	buf.WriteString("- Tier: Free, Premium, Ultimate\n")
+	buf.WriteString("- Offering: GitLab.com, GitLab Self-Managed, GitLab Dedicated\n\n")
+	buf.WriteString("{{< /details >}}\n\n")
+
 	// Custom title and intro content (from README)
-	buf.WriteString("![GLab](../assets/glab-logo.png)\n\n")
 	buf.WriteString("GLab is an open source GitLab CLI tool. It brings GitLab to your terminal, next to where you are already working with `git` and your code, without switching between windows and browser tabs. While it's powerful for issues and merge requests, `glab` does even more:\n\n")
 	buf.WriteString("- View, manage, and retry CI/CD pipelines directly from your CLI.\n")
 	buf.WriteString("- Create changelogs.\n")
@@ -357,7 +361,7 @@ func GenRootMarkdownCustom(cmd *cobra.Command, w io.Writer) error {
 	buf.WriteString("- Ask GitLab Duo Chat questions about Git.\n")
 	buf.WriteString("- Manage GitLab agents for Kubernetes.\n\n")
 	buf.WriteString("`glab` is available for repositories hosted on GitLab.com, GitLab Dedicated, and GitLab Self-Managed. It supports multiple authenticated GitLab instances, and automatically detects the authenticated hostname from the remotes available in your working Git directory.\n\n")
-	buf.WriteString("![command example](../assets/glabgettingstarted.gif)\n\n")
+	buf.WriteString("![command example](img/glabgettingstarted.gif)\n\n")
 
 	// Install and authenticate sections (moved up, with README links)
 	buf.WriteString("## Install the CLI\n\n")
