@@ -3,6 +3,8 @@ package logout
 import (
 	"fmt"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	"gitlab.com/gitlab-org/cli/internal/iostreams"
 
 	"github.com/MakeNowJust/heredoc/v2"
@@ -12,6 +14,15 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/config"
 )
 
+// fieldsToClear a collection of all fields to clear from the config when logging out.
+var fieldsToClear = []string{
+	"token",
+	"job_token",
+	"is_oauth2",
+	"oauth2_refresh_token",
+	"oauth2_expiry_date",
+}
+
 type options struct {
 	io       *iostreams.IOStreams
 	config   func() config.Config
@@ -37,6 +48,9 @@ func NewCmdLogout(f cmdutils.Factory) *cobra.Command {
 			Logout of a specific instance
 			- glab auth logout --hostname gitlab.example.com
 		`),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			return opts.run()
 		},
@@ -50,8 +64,10 @@ func NewCmdLogout(f cmdutils.Factory) *cobra.Command {
 func (o *options) run() error {
 	cfg := o.config()
 
-	if err := cfg.Set(o.hostname, "token", ""); err != nil {
-		return err
+	for _, key := range fieldsToClear {
+		if err := cfg.Set(o.hostname, key, ""); err != nil {
+			return err
+		}
 	}
 
 	if err := cfg.Write(); err != nil {
