@@ -25,7 +25,7 @@ func TestChangelogGenerate(t *testing.T) {
 		tc.MockRepositories.EXPECT().
 			GenerateChangelogData(37777023, gitlab.GenerateChangelogDataOptions{Version: gitlab.Ptr("1.0.0")}).
 			Return(&gitlab.ChangelogData{
-				Notes: "## 1.0.0 (2023-04-02)\n\n### FirstName LastName firstname@lastname.com (1 changes)\n\n- [inital commit](gitlab-org/cli@somehash ([merge request](gitlab-org/cli!1))\n",
+				Notes: "## 1.0.0 (2023-04-02)\n\n### FirstName LastName firstname@lastname.com (1 changes)\n\n- [initial commit](gitlab-org/cli@somehash ([merge request](gitlab-org/cli!1))\n",
 			}, nil, nil),
 	)
 
@@ -41,7 +41,7 @@ func TestChangelogGenerate(t *testing.T) {
 
 	assert.Empty(t, out.ErrBuf.String())
 
-	expectedStr := "## 1.0.0 (2023-04-02)\n\n### FirstName LastName firstname@lastname.com (1 changes)\n\n- [inital commit](gitlab-org/cli@somehash ([merge request](gitlab-org/cli!1))\n"
+	expectedStr := "## 1.0.0 (2023-04-02)\n\n### FirstName LastName firstname@lastname.com (1 changes)\n\n- [initial commit](gitlab-org/cli@somehash ([merge request](gitlab-org/cli!1))\n"
 	assert.Equal(t, expectedStr, out.OutBuf.String())
 }
 
