@@ -8,6 +8,7 @@ import (
 	agentGetTokenCmd "gitlab.com/gitlab-org/cli/internal/commands/cluster/agent/get_token"
 	agentListCmd "gitlab.com/gitlab-org/cli/internal/commands/cluster/agent/list"
 	agentTokenCmd "gitlab.com/gitlab-org/cli/internal/commands/cluster/agent/token"
+	agentTokenCacheCmd "gitlab.com/gitlab-org/cli/internal/commands/cluster/agent/token_cache"
 	agentUpdateKubeconfigCmd "gitlab.com/gitlab-org/cli/internal/commands/cluster/agent/update_kubeconfig"
 )
 
@@ -21,6 +22,7 @@ func NewCmdAgent(f cmdutils.Factory) *cobra.Command {
 	cmdutils.EnableRepoOverride(agentCmd, f)
 
 	agentCmd.AddCommand(agentTokenCmd.NewCmd(f))
+	agentCmd.AddCommand(agentTokenCacheCmd.NewCmd(f))
 	agentCmd.AddCommand(agentListCmd.NewCmdAgentList(f))
 	agentCmd.AddCommand(agentGetTokenCmd.NewCmdAgentGetToken(f))
 	agentCmd.AddCommand(agentUpdateKubeconfigCmd.NewCmdAgentUpdateKubeconfig(f))
