@@ -5,6 +5,8 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	labelCreateCmd "gitlab.com/gitlab-org/cli/internal/commands/label/create"
 	labelDeleteCmd "gitlab.com/gitlab-org/cli/internal/commands/label/delete"
+	labelUpdateCmd "gitlab.com/gitlab-org/cli/internal/commands/label/edit"
+	labelGetCmd "gitlab.com/gitlab-org/cli/internal/commands/label/get"
 	labelListCmd "gitlab.com/gitlab-org/cli/internal/commands/label/list"
 )
 
@@ -20,6 +22,8 @@ func NewCmdLabel(f cmdutils.Factory) *cobra.Command {
 	labelCmd.AddCommand(labelListCmd.NewCmdList(f))
 	labelCmd.AddCommand(labelCreateCmd.NewCmdCreate(f))
 	labelCmd.AddCommand(labelDeleteCmd.NewCmdDelete(f))
+	labelCmd.AddCommand(labelUpdateCmd.NewCmdEdit(f))
+	labelCmd.AddCommand(labelGetCmd.NewCmdGet(f))
 
 	return labelCmd
 }
