@@ -1,6 +1,7 @@
 package update
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"regexp"
@@ -8,10 +9,11 @@ import (
 
 	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 
-	"github.com/AlecAivazis/survey/v2"
+	"github.com/charmbracelet/huh"
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/commands/mr/mrutils"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
@@ -128,18 +130,17 @@ func NewCmdUpdate(f cmdutils.Factory) *cobra.Command {
 					}
 					fmt.Fprintf(f.IO().StdOut, "\n")
 
-					action, err := confirmUpdateSurvey()
+					action, err := confirmUpdateSurvey(cmd.Context(), f)
 					if err != nil {
-						// Handle interrupt or EOF gracefully
-						if strings.Contains(err.Error(), "interrupt") || strings.Contains(err.Error(), "EOF") {
-							fmt.Fprintf(f.IO().StdOut, "Operation cancelled.\n")
+						// iostreams.Run already prints "Cancelled." for user cancellation
+						if errors.Is(err, iostreams.ErrUserCancelled) {
 							return nil
 						}
-						return fmt.Errorf("failed to prompt for confirmation: %w", err)
+						return err
 					}
 
 					if action == cmdutils.CancelAction {
-						fmt.Fprintf(f.IO().StdOut, "Operation cancelled.\n")
+						fmt.Fprintf(f.IO().StdOut, "Cancelled.\n")
 						return nil
 					}
 				}
@@ -343,29 +344,22 @@ func NewCmdUpdate(f cmdutils.Factory) *cobra.Command {
 	return mrUpdateCmd
 }
 
-func confirmUpdateSurvey() (cmdutils.Action, error) {
-	const (
-		proceedLabel = "Proceed with changes"
-		cancelLabel  = "Cancel"
-	)
+func confirmUpdateSurvey(ctx context.Context, f cmdutils.Factory) (cmdutils.Action, error) {
+	shouldProceed := false // default value
 
-	options := []string{proceedLabel, cancelLabel}
+	confirm := huh.NewConfirm().
+		Title("What would you like to do?").
+		Affirmative("Proceed with changes").
+		Negative("Cancel").
+		Value(&shouldProceed)
 
-	var result string
-	confirm := &survey.Select{
-		Message: "What would you like to do?",
-		Options: options,
-	}
-
-	err := survey.AskOne(confirm, &result)
+	err := f.IO().Run(ctx, confirm)
 	if err != nil {
 		return cmdutils.CancelAction, fmt.Errorf("could not prompt: %w", err)
 	}
 
-	switch result {
-	case proceedLabel:
+	if shouldProceed {
 		return cmdutils.SubmitAction, nil
-	default:
-		return cmdutils.CancelAction, nil
 	}
+	return cmdutils.CancelAction, nil
 }
