@@ -9,6 +9,8 @@ import (
 	"strconv"
 	"time"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
@@ -85,6 +87,9 @@ func NewCmdUpload(f cmdutils.Factory) *cobra.Command {
 			    }
 			  ]'
 		`),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := opts.complete(cmd.Flags(), args); err != nil {
 				return err
@@ -154,7 +159,7 @@ func (o *options) run() error {
 	color := o.io.Color()
 	var resp *gitlab.Response
 
-	o.io.Logf("%s Validating tag %s=%s %s=%s\n",
+	o.io.LogInfof("%s Validating tag %s=%s %s=%s\n",
 		color.ProgressIcon(),
 		color.Blue("repo"), repo.FullName(),
 		color.Blue("tag"), o.tagName)
@@ -173,6 +178,6 @@ func (o *options) run() error {
 		return cmdutils.WrapError(err, "creating release assets failed.")
 	}
 
-	o.io.Logf(color.Bold("%s Upload succeeded after %0.2fs.\n"), color.GreenCheck(), time.Since(start).Seconds())
+	o.io.LogInfof(color.Bold("%s Upload succeeded after %0.2fs.\n"), color.GreenCheck(), time.Since(start).Seconds())
 	return nil
 }
