@@ -1,3 +1,5 @@
+//go:build !integration
+
 package glrepo
 
 import (
@@ -7,7 +9,8 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
-	"gitlab.com/gitlab-org/cli/pkg/git"
+	"gitlab.com/gitlab-org/cli/internal/git"
+	"gitlab.com/gitlab-org/cli/internal/glinstance"
 )
 
 func eq(t *testing.T, got any, expected any) {
@@ -19,9 +22,9 @@ func eq(t *testing.T, got any, expected any) {
 
 func TestFindByName(t *testing.T) {
 	list := Remotes{
-		&Remote{Remote: &git.Remote{Name: "mona"}, Repo: New("monalisa", "myfork")},
-		&Remote{Remote: &git.Remote{Name: "origin"}, Repo: New("monalisa", "octo-cat")},
-		&Remote{Remote: &git.Remote{Name: "upstream"}, Repo: New("hubot", "tools")},
+		&Remote{Remote: &git.Remote{Name: "mona"}, Repo: New("monalisa", "myfork", glinstance.DefaultHostname)},
+		&Remote{Remote: &git.Remote{Name: "origin"}, Repo: New("monalisa", "octo-cat", glinstance.DefaultHostname)},
+		&Remote{Remote: &git.Remote{Name: "upstream"}, Repo: New("hubot", "tools", glinstance.DefaultHostname)},
 	}
 
 	r, err := list.FindByName("upstream", "origin")
@@ -59,7 +62,7 @@ func TestTranslateRemotes(t *testing.T) {
 	identityURL := func(u *url.URL) *url.URL {
 		return u
 	}
-	result := TranslateRemotes(gitRemotes, identityURL)
+	result := TranslateRemotes(gitRemotes, identityURL, glinstance.DefaultHostname)
 
 	if len(result) != 2 {
 		t.Errorf("got %d results", len(result))
